// Cpp program for the above approach
#include <bits/stdc++.h>
using namespace std;

// Function to form edge between
// two vertices src and dest
void add_edge(vector<pair<int,int>> adj[],
              int src, int dest,int w)
{
    adj[src].push_back(make_pair(dest,w));
    adj[dest].push_back(make_pair(src,w));
}

// Function which finds all the paths
// and stores it in paths array
void find_paths(vector<vector<pair<int,int>>>& paths,
                vector<pair<int,int>>& path,
                vector<pair<int,int>> parent[],
                int n, int u)
{
    // Base Case
    if (u == -1) {
        paths.push_back(path);
        return;
    }

    // Loop for all the parents
    // of the given vertex
    for (auto par : parent[u]) {

        // Insert the current
        // vertex in path
        path.push_back(make_pair(u,par.second));

        // Recursive call for its parent
        find_paths(paths, path, parent,
                   n, par.first);

        // Remove the current vertex
        path.pop_back();
    }
}

// Function which performs bfs
// from the given source vertex
void bfs(vector<pair<int,int>>  adj[],
         vector<pair<int,int>> parent[],
         int n, int start)
{
    // dist will contain shortest distance
    // from start to every other vertex
    vector<int> dist(n, INT_MAX);

    queue<int> q;

    // Insert source vertex in queue and make
    // its parent -1 and distance 0
    q.push(start);
    parent[start] = {make_pair(-1,0)};
    dist[start] = 0;

    // Until Queue is empty
    while (!q.empty()) {
        int u = q.front();
        q.pop();
        for (auto v : adj[u]) {
            if (dist[v.first] > dist[u] + 1) {

                // A shorter distance is found
                // So erase all the previous parents
                // and insert new parent u in parent[v]
                dist[v.first] = dist[u] + 1;
                q.push(v.first);
                parent[v.first].clear();
                parent[v.first].push_back(make_pair(u,v.second));
            }
            else if (dist[v.first] == dist[u] + 1) {

                // Another candidate parent for
                // shortes path found
                parent[v.first].push_back(make_pair(u,v.second));
            }
        }
    }
}

// Function which prints all the paths
// from start to end
void print_path(vector<pair<int,int>>  adj[],
                 int n, int start, int ending)
{
    vector<vector<pair<int,int>>> paths;
    vector<pair<int,int>> path;
    vector<pair<int,int>> parent[n];

    // Function call to bfs
    bfs(adj, parent, n, start);

    // Function call to find_paths
    find_paths(paths, path, parent, n, ending);
    int MX = 0;

    vector<pair<int,int>> resp;

    for (auto v : paths) {
        int mn = v[1].second,mx = v[1].second;
        for (auto u : v)
        {
            if (mn > u.second && u.second != 0)
                mn = u.second;
            if (mx < u.second)
                mx = u.second;
        }
        if (MX < mx - mn)
        {
            resp = v;
            MX = mx - mn;
        }
    }
    cout << resp.size() - 1 << endl;
    reverse(resp.begin(),resp.end());
    for (auto u : resp)
        cout << u.first + 1 << " ";
    cout << endl;
}

// Driver Code
int main()
{
    int n,m;
    cin >> n >> m;
    vector<pair<int,int>> adj[n];
    for (int i = 0;i < m;i ++)
    {
        int x,y,w;
        cin >> x >> y >> w;
        add_edge(adj,x - 1,y - 1,w);
    }
    print_path(adj,n,0,n - 1);
    return 0;
}
