#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ui = unsigned int;
using ull = unsigned long long;
using ld = long double;
using pii = pair<int, int>;
using pll = pair<long long, long long>;

const int inf = 1e9;
const ll inf64 = 1e18;

struct output {
    int s, t;

    void print() {
        cout << s << " " << t << "\n";
    }

    bool operator == (const output& o) const {
        return s == o.s;
    }
};

struct RangeTree {
    int n = 0; // [0, n)
    vector<int> a;

    struct Node {
        int mx = 0;
        int pr = 0;
        int sf = 0;
        int lx = 0;
        int rx = 0;

        Node() = default;

        Node(int x) {
            mx = 1;
            pr = 1;
            sf = 1;
            lx = x;
            rx = x;
        }
    };

    vector<Node> t;

    Node merge(const Node& l, const Node& r) const {
        Node res;
        res.mx = max(l.mx, r.mx);
        res.pr = l.pr;
        res.sf = r.sf;
        res.lx = l.lx;
        res.rx = r.rx;

        if (l.rx + 1 >= r.lx) {
            int flag = int(l.rx + 1 > r.lx);
            res.mx = max(res.mx, l.sf + r.pr - flag);
            if (l.pr == l.rx - l.lx + 1) res.pr = max(res.pr, l.pr + r.pr - flag);
            if (r.sf == r.rx - r.lx + 1) res.sf = max(res.sf, l.sf + r.sf - flag);
        }
        return res;
    }

    RangeTree() = default;

    RangeTree(const vector<int>& a_) {
        a = a_;
        n = (int) a_.size();
        t.resize(4 * n);
        build(1, 0, n - 1);
    }

    void build(int v, int tl, int tr) {
        if (tl == tr) {
            t[v] = Node(a[tl]);
        } else {
            int tm = (tl + tr) >> 1;
            build(v << 1, tl, tm);
            build(v << 1 | 1, tm + 1, tr);
            t[v] = merge(t[v << 1], t[v << 1 | 1]);
        }
    }

    void update(int v, int tl, int tr, int i) {
        if (tl == tr) {
            t[v] = Node(a[tl]);
        } else {
            int tm = (tl + tr) >> 1;
            if (i <= tm) update(v << 1, tl, tm, i);
            else update(v << 1 | 1, tm + 1, tr, i);
            t[v] = merge(t[v << 1], t[v << 1 | 1]);
        }
    }

    void update(int i) {
        a[i]++;
        update(1, 0, n - 1, i);
    }

    int query() {
        return t[1].mx;
//        Node res;
//        for (int i = 0; i < n; i++)
//            res = merge(res, Node(a[i]));
//        build(1, 0, n - 1);
//        assert(res.mx == t[1].mx);
//        return res.mx;
    }
};

struct input {
    int n, m;
    vector<int> a;

    input() = default;

    void read() {
        cin >> n >> m;
        a.resize(n);
        for (int i = 0; i < n; i++)
            cin >> a[i];
    }

    void print() {
        cout << n << " " << m << "\n";
        for (int i = 0; i < n; i++)
            cout << a[i] << " ";
        cout << "\n";
    }

    void gen() {
        static mt19937 rnd(42);
        const int MAXN = 100;
        const int MAXM = 100;
        n = rnd() % MAXN + 1;
        m = rnd() % MAXM + 1;
        a.resize(n);
        for (int i = 0; i < n; i++) {
            a[i] = (i > 0 ? a[i - 1] : 0) + 1 + rnd() % MAXM;
        }
    }

    int calculate(int t) {
        if (t < 0 || t >= m)
            return -10;
        int res = 0, cur = 0, last = -inf;
        for (int i = 0; i < n; i++) {
            int day = (a[i] + t) / m;
            if (day > last + 1) {
                cur = 1;
            } else if (day == last + 1) {
                cur++;
            }
            last = day;
            res = max(res, cur);
        }
        return res;
    }

    output fast() {
        vector<int> d(n);
        vector<pii> events;
        for (int i = 0; i < n; i++) {
            d[i] = a[i] / m;
            int t = (d[i] + 1) * m - a[i];
            if (0 <= t && t < m)
                events.emplace_back(t, i);
        }
        sort(events.begin(), events.end());
        RangeTree rt(d);
        int bs = -1, bt = -1;
        for (int i = 0; i <= (int) events.size(); i++) {
            if (i == 0 || i == (int) events.size() || events[i].first != events[i - 1].first) {
                // update res
                int tmp = rt.query();
                if (tmp > bs) {
                    bs = tmp;
                    bt = i ? events[i - 1].first : 0;
                }
            }
            if (i < (int) events.size()) {
                // update structure
                rt.update(events[i].second);
            }
        }
//        assert(calculate(bt) == bs);
        return output{bs, bt};
    }

    output slow() {
        int bs = -1, bt = -1;
        for (int t = 0; t < m; t++) {
            int tmp = calculate(t);
            if (tmp > bs) {
                bs = tmp;
                bt = t;
            }
        }
        return output{bs, bt};
    }
};

void test_case() {
    input in;
    in.read();
    output res = in.fast();
    res.print();
}

void work() {
    int t;
    cin >> t;
    while (t--)
        test_case();
}

void test() {
    for (int t = 1;;t++) {
        input in;
        in.gen();
        input in_fs = in;
        input in_sl = in;
        output fs = in_fs.fast();
        output sl = in_sl.slow();
        if (fs == sl) {
            cout << "OK" << endl;
            fs.print();
            cout << "\n=========" << endl;
        } else {
            cout << "WA " << t << "\n";
            cout << "exp\n";
            sl.print();
            cout << "\n=========\n";
            cout << "fnd\n";
            fs.print();
            cout << "\n=========\n";
            in.print();
            break;
        }
    }
}

int main() {

#ifdef DEBUG
    freopen("input.txt", "r", stdin);
#endif

    ios_base::sync_with_stdio(0);
    cin.tie(0);

    work();
//    test();

    return 0;
}
