#include <iostream>
#include <cstdio>
#include <cassert>
#include <algorithm>
#include <fstream>
#include <vector>
#include <unordered_map>

using namespace std;

struct TreeVal {
    TreeVal() : pref(0), suf(0), total(0), pref_sz(0), suf_sz(0) {}

    TreeVal(int pref, int suf, int total, int pref_sz, int suf_sz) :
            pref(pref), suf(suf), total(total), pref_sz(pref_sz), suf_sz(suf_sz) {}

    int pref, suf, total;
    int pref_sz, suf_sz;
};

TreeVal sum(const TreeVal &a, const TreeVal &b, int szl, int szr) {
    int pref = a.pref, pref_sz = a.pref_sz;
    if (pref_sz == szl) {
        pref += b.pref;
        pref_sz += b.pref_sz;
    }
    int suf = b.suf, suf_sz = b.suf_sz;
    if (szr == suf_sz) {
        suf += a.suf;
        suf_sz += a.suf_sz;
    }
    int total = max(max(a.total, b.total), a.suf + b.pref);
    return TreeVal(pref, suf, total, pref_sz, suf_sz);
}

struct Tree {
    explicit Tree(int sz) {
        _sz = sz;
        d.resize(4 * sz + 1);
    }

    void update(int i, int l, int r, int pos, TreeVal val) {
        if (l > pos || r < pos)
            return;
        if (l == r) {
            d[i] = val;
            return;
        }
        int mid = (l + r) / 2;
        update(2 * i, l, mid, pos, val);
        update(2 * i + 1, mid + 1, r, pos, val);
        d[i] = sum(d[2 * i], d[2 * i + 1], mid - l + 1, r - mid);
    }

    void update(int pos, TreeVal val) {
        update(1, 0, _sz - 1, pos, val);
    }

    void debug(int i) {
        cout << d[i].pref_sz << " " << d[i].suf_sz << " " << d[i].pref << " " << d[i].suf << " " << d[i].total << endl;
    }

    int get_total() {
//        debug(1);
//        debug(2);
//        debug(3);
        return d[1].total;
    }

    vector<TreeVal> d;
    int _sz;
};

struct Event {
    int time, i;
    int val;
    int weight;
};

bool cmp(const Event &e1, const Event &e2) {
    return e1.time < e2.time;
}

pair <int, int> solve(int m, vector <int> a) {
    int n = (int)a.size();
    Tree tr(n - 1);
    vector<Event> events;
    for (int i = 0; i < n - 1; i++) {
        int l = a[i], r = a[i + 1];
        if (r - l >= 2 * m)
            continue;
        int l1 = l % m, r1 = r % m;
        if (r1 > l1) {
            if (l / m != r / m) {
                events.push_back({0, i, 1, 1});
                events.push_back({m - r1, i, 0, 0});
                events.push_back({m - l1, i, 1, 1});
            } else {
                events.push_back({0, i, 1, 0});
                events.push_back({m - r1, i, 1, 1});
                events.push_back({m - l1, i, 1, 0});
            }
        } else {
            if (l / m + 1 == r / m) {
                events.push_back({0, i, 1, 1});
                if (l1 != r1) {
                    events.push_back({m - l1, i, 1, 0});
                    events.push_back({m - r1, i, 1, 1});
                }
            } else {
                events.push_back({0, i, 0, 0});
                events.push_back({m - l1, i, 1, 1});
                events.push_back({m - r1, i, 0, 0});
            }
        }
    }

    events.push_back({m + 1, 0, 0});
    sort(events.begin(), events.end(), cmp);
    int res = 0, time_res = 0;
    for (int i = 0; i < (int) events.size(); i++) {
        if (i > 0 && events[i].time != events[i - 1].time) {
            int cur_res = tr.get_total();
//            cout << "get total " << cur_res << endl;
            if (res < cur_res) {
                res = cur_res;
                time_res = events[i - 1].time;
            }
        }
        tr.update(events[i].i, TreeVal(
                events[i].weight, events[i].weight, events[i].weight,
                events[i].val, events[i].val));
//        cout << events[i].time << " update " << events[i].i << " " << events[i].val << " " << events[i].weight << endl;
    }
    return {res + 1, time_res};
}

pair <int, int> dummy(int m, vector <int> a) {
    int max_res = -1;
    int time = -1;
    for (int shift = 0; shift < m; shift++) {
        vector <int> days;
        for (int i = 0; i < (int)a.size(); i++)
            days.push_back((a[i] + shift) / m);
        int res = 1, cur = 1;
        for (int i = 1; i < (int)days.size(); i++) {
            if (days[i] == days[i - 1] + 1)
                cur += 1;
            else if (days[i] > days[i - 1] + 1)
                cur = 1;
            res = max(res, cur);
        }
        if (res > max_res) {
            max_res = res;
            time = shift;
        }
    }
    return {max_res, time};
}

pair <int, vector <int> > gen() {
    int maxkek = 100;
    int n = rand() % maxkek + 1;
    int m = rand() % maxkek + 1;
    vector <int> a(n);
    for (int i = 0; i < n; i++)
        a[i] = rand() % maxkek;
    sort(a.begin(), a.end());
    a.resize(unique(a.begin(), a.end()) - a.begin());
    return {m, a};
}

void solve() {
    int t;
    cin >> t;
    for (int i = 0; i < t; i++) {
        int n, m; cin >> n >> m;
        vector <int> a(n);
        for (int j = 0; j < n; j++)
            cin >> a[j];
        pair <int, int> res = solve(m, a);
        cout << res.first << " " << res.second << endl;
    }
}

void stress() {
    for (int test_num = 1; true; test_num++) {
        pair <int, vector <int> > test = gen();
        pair <int, int> dummy_res = dummy(test.first, test.second);
        pair <int, int> my_res = solve(test.first, test.second);
        if (dummy_res != my_res) {
            cout << "Test #" << test_num << ": WA" << endl;
            cout << (int)test.second.size() << " " << test.first << endl;
            for (int a : test.second)
                cout << a << " ";
            cout << endl << endl;
            cout << "Dummy: " << dummy_res.first << " " << dummy_res.second << endl;
            cout << "   My: " << my_res.first << " " << my_res.second << endl;
            break;
        } else
            cout << "Test #" << test_num << ": OK" << endl;
    }
}

int main() {
//    freopen("input.txt", "r", stdin);
//    freopen("output.txt", "w", stdout);

    solve();
//    stress();

    return 0;
}
