#include <cmath>
#include <iostream>
#include <set>
#include <vector>

using namespace std;

int n, k;
set<pair<int, int>> currentLess;
vector<vector<int>> matrix;
vector<int> parent;
vector<int> subtreeSize;

struct Trie
{
    Trie* letter[26];
    long long ends, numOfWords;
    Trie()
    {
        ends = 0;
        numOfWords = 0;
        for (long long i = 0; i <= 25; i++)
            letter[i] = nullptr;
    };
    void add(string word)
    {
        Trie* pos = this;
        for (long long i = 0; i < word.size(); i++)
        {
            long long ch = (word[i] - 'a');
            if (pos->letter[ch] == nullptr)
                pos->letter[ch] = new Trie();
            pos->numOfWords++;
            pos = pos->letter[ch];
        }
        pos->numOfWords++;
        pos->ends++;
    }

    long long getNumOfWords()
    {
        if (this == nullptr)
            return 0;
        return this->numOfWords;
    }
};

Trie* optimise(Trie* pos) {
    if (pos == nullptr)
        return nullptr;
    for (int i = 0; i < 26; i++)
        pos->letter[i] = optimise(pos->letter[i]);
    for (int i = 0; i < 26; i++)
        if (pos->numOfWords == pos->letter[i]->getNumOfWords())
            return pos->letter[i];
    return pos;
}

int compress(Trie* pos) {
    int curNum = parent.size();

    subtreeSize.push_back(pos->numOfWords);
    parent.push_back(-1);
    matrix.push_back({});

    for (int i = 0; i < 26; i++) {
        if (pos->letter[i] == nullptr)
            continue;
        int nextNum = compress(pos->letter[i]);
        matrix[curNum].push_back(nextNum);
        parent[nextNum] = curNum;
    }
    return curNum;
}

void addToSet(const vector<vector<int>>& matrix, int v = 0) {
    //cout << v << " " << subtreeSize[v] << ' ';
    if (subtreeSize[v] <= k) {
        //cout << "Adding!\n";
        currentLess.insert({subtreeSize[v], v});
    }
    else {
        //cout << "\n";
        for (int u : matrix[v])
            addToSet(matrix, u);
    }
}

int main()
{
    cin >> n >> k;
    Trie* trie = new Trie();
    for (int i = 0; i < n; i++) {
        string s;
        cin >> s;
        trie->add(s);
    }
    trie = optimise(trie);
    compress(trie);

    /*for (int i = 0; i < matrix.size(); i++) {
        cout << i << ":\n";
        cout << "parent = " << parent[i] << '\n';
        cout << "subtreeSize = " << subtreeSize[i] << '\n';
        cout << "matrix = ";
        for (int v : matrix[i])
            cout << v << ' ';
        cout << '\n';
    }*/

    addToSet(matrix);

    int ans = 0;

    while (!currentLess.empty()) {
        /*cout << "--------\n";
        for (auto p : currentLess)
            cout << "- " << p.second << endl;
        cout << "--------\n";*/
        ans++;
        int maxV = currentLess.rbegin()->second;
        currentLess.erase(*currentLess.rbegin());

        for (int p = parent[maxV]; p != -1; p = parent[p]) {
            subtreeSize[p] -= subtreeSize[maxV];
            if (subtreeSize[p] <= k) {
                for (int u : matrix[p])
                    currentLess.erase({subtreeSize[u], u});
                currentLess.insert({subtreeSize[p], p});
            }
        }
    }

    cout << ans;
    return 0;
}
/*

int aaamain() {
    n = 4;
    k = 2;
    vector<vector<int>> matrix = {
        {1, 2},
        {3},
        {},
        {}
    };
    vector<int> parent = {-1, 0, 0, 1};
    marked = {true, true, true, true};
    subtreeSize.resize(n, -1);

    // calculateSubtreeSizes(matrix);
    addToSet(matrix);
    for (auto p : currentLess)
        cout << "- " << p.second << endl;

    int ans = 0;

    */
/*while (!currentLess.empty()) {
        for (auto p : currentLess)
            cout << "- " << p.second << endl;
        cout << "--------\n";
        ans++;
        int maxV = currentLess.rend()->second;
        currentLess.erase(*currentLess.rend());

        for (int p = parent[maxV]; p != -1; p = parent[p]) {
            subtreeSize[p] -= subtreeSize[maxV];
            if (subtreeSize[p] <= k) {
                for (int u : matrix[p])
                    currentLess.erase({subtreeSize[u], u});
                currentLess.insert({subtreeSize[p], p});
            }
        }
    }*//*


    cout << ans;
}*/
