#include <iostream>
#include <vector>
#include <queue>
#include <algorithm>

using namespace std;

const int maxN = 3e5 + 10;
const int maxA = 26;
const int INF = 1e9 + 7;

struct edge {
  int end;
  int c;
};


vector<int> bfs(vector<vector<edge>>& g, int n, int s, vector<int>& order) {
  queue<int> q;
  vector<int> dist(n, -1);
  vector<bool> used(n, false);

  q.push(s);
  dist[s] = 0;
  used[s] = true;
  while (!q.empty()) {
    int v = q.front();
    //cerr << v << " " << dist[v] << "\n";
    order.push_back(v);
    q.pop();
    for (auto e : g[v]) {
      //cerr << "(" << e.end << " " << e.c << ")" << "\n";
      int u = e.end;
      if (!used[u]) {
        dist[u] = dist[v] + 1;
        q.push(u);
        used[u] = true;
      }
    }
  }
  return dist;
}

int findopt(vector<int>& minpref, vector<int>& maxsuf, vector<int>& prpref, vector<int>& prsuf, vector<int>& distpref, 
    vector<int>& distsuf, int n, int d, vector<int>& path) {
  int ans = -INF;
  int pt = -1;

  for (int v = 0; v < n; v++) {
    if (distpref[v] + distsuf[v] == d && maxsuf[v] - minpref[v] > ans) {
      ans = maxsuf[v] - minpref[v];
      pt = v;
    }
  }

  int v = pt;
  while(v != -1) {
    path.push_back(v);
    v = prpref[v];
  }

  reverse(path.begin(), path.end());

  v = pt;
  while(v != -1) {
    v = prsuf[v];
    if (v != -1) {
      path.push_back(v);
    }
  }
  //cerr << pt << "\n";
  return ans;
}

void findminpref(vector<vector<edge>>& g, vector<int>& order, vector<int>& dist, vector<int>& minpref, vector<int>& pr) {
  for (int v : order) {
    for (auto e : g[v]) {
      int u = e.end;
      if (dist[u] != -1 && dist[u] + 1 == dist[v]) {
        if (minpref[v] > min(minpref[u], e.c)) {
          minpref[v] = min(minpref[u], e.c);
          pr[v] = u;

        }
      }
    }
  }
}

void findmaxpref(vector<vector<edge>>& g, vector<int>& order, vector<int>& dist, vector<int>& maxpref, vector<int>& pr) {
  for (int v : order) {
    for (auto e : g[v]) {
      int u = e.end;
      if (dist[u] != -1 && dist[u] + 1 == dist[v]) {
        if (maxpref[v] < max(maxpref[u], e.c)) {
          maxpref[v] = max(maxpref[u], e.c);
          pr[v] = u;
        }
      }
    }
  }
}


int main () {
  int n, m;
  cin >> n >> m;
  vector<vector<edge>> g(n);

  for (int i = 0; i < m; i++) {
    int u, v, c;
    cin >> u >> v >> c;
    u--, v--;
    g[u].push_back({v, c});
    g[v].push_back({u, c});
  }

  vector<int> order, order_rev;
  vector<int> dist = bfs(g, n, 0, order);
  vector<int> dist_rev = bfs(g, n, n - 1, order_rev);

  int d = dist[n - 1];
  //cerr << d << "\n";

  vector<int> minstart(n, INF);
  vector<int> maxstart(n, -INF);
  vector<int> minstartpr(n, -1);
  vector<int> maxstartpr(n, -1);

  findminpref(g, order, dist, minstart, minstartpr);
  findmaxpref(g, order, dist, maxstart, maxstartpr);

  for (int i = 0; i < n; i++) {
    //cerr << i + 1 << ": " << minstart[i] << "\n";
  }




  vector<int> minend(n, INF);
  vector<int> maxend(n, -INF);
  vector<int> minendpr(n, -1);
  vector<int> maxendpr(n, -1);

  findminpref(g, order_rev, dist_rev, minend, minendpr);
  findmaxpref(g, order_rev, dist_rev, maxend, maxendpr);

  for (int i = 0; i < n; i++) {
    //cerr << i + 1 << ": " << maxend[i] << "\n";
  }


  vector<int> path;
  int ans = findopt(minstart, maxend, minstartpr, maxendpr, dist, dist_rev, n, d, path);

  vector<int> path_rev;
  int ans_rev = findopt(minend, maxstart, minendpr, maxstartpr, dist_rev, dist, n, d, path_rev);

  reverse(path_rev.begin(), path_rev.end());

  vector<int> ans_path;

  if (ans > ans_rev) {
    //cerr << ans << "\n";
    ans_path = path;
  } else {
    //cerr << ans_rev << "\n";
    ans_path = path_rev;
  }


  cout << ans_path.size() - 1 << "\n";
  for (int i : ans_path) {
    cout << i + 1 << " ";
  }
  cout << "\n";

}
