#include <iostream>
#include <climits>
#include <cstddef>
#include <cmath>
#include <vector>
#include <iomanip>
#include <cassert>
#include <algorithm>
#include <map>
#include <set>
#include <unordered_map>
#include <unordered_set>
#include <queue>

using namespace std;

void solve();

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0);

    #ifdef HOME
        freopen("input.txt", "r", stdin);
        freopen("output.txt", "w", stdout);
        clock_t start_clock = clock();
    // #else
    //  freopen(".in", "r", stdin);
    //  freopen(".out", "w", stdout);
    #endif
    
    solve();

    #ifdef HOME
        // system("pause");
        printf("\n\nfinished in %.3f sec", static_cast<float>(clock() - start_clock) / CLOCKS_PER_SEC);
    #endif
}

// bool comp(size_t lhs, size_t rhs) {
//     size_t left = a[lhs].first + a[lhs].second;
//     size_t right = a[rhs].first + a[rhs].second;
//     return left < right;
// };

struct vert {
    size_t id;
    size_t white;
    size_t black;
};

struct cmp_white {
    bool operator()(vert a, vert b) const {
        size_t left = a.white + a.black;
        size_t right = b.white + b.black;
        if (left != right) {
            return left < right;
        }
        return a.white < b.white;
    }
};

struct cmp_black {
    bool operator()(vert a, vert b) const {
        size_t left = a.white + a.black;
        size_t right = b.white + b.black;
        if (left != right) {
            return left < right;
        }
        return a.black < b.black;
    }
};

struct edge {
    size_t v;
    size_t u;
    char color;

    edge() = default;
    edge(size_t _v, size_t _u, char _color) 
    : v(_v), u(_u), color(_color) {}
};

void solve() {
    size_t t;
    cin >> t;

    for (size_t iter = 0; iter != t; ++iter) {
        size_t n;
        cin >> n;

        bool ok = true;
        multiset<vert, cmp_white> white;
        multiset<vert, cmp_black> black;
        multiset<vert, cmp_white> both_white;
        multiset<vert, cmp_black> both_black;

        for (size_t i = 0; i != n; ++i) {
            vert v;
            v.id = i;
            cin >> v.white >> v.black;

            if (n == 1) {
                if (v.white == 0 && v.black == 0) {
                    ok = true;
                } else {
                    ok = false;
                }
            }
            
            if (v.white == 0) {
                black.insert(v);
            } else {
                if (v.black == 0) {
                    white.insert(v);
                } else {
                    both_white.insert(v);
                    both_black.insert(v);
                }
            }
        }

        // for (auto it : both) {
        //     cout << it.id << '\n';
        // }

        if (n == 1) {
            cout << (ok ? "Yes\n" : "No\n");
            continue;
        }

        // cerr << white.size() << ' ' << black.size() << ' ' << both.size() << '\n';

        vector<edge> ans;
        while (ans.size() < n - 1) {
            // cerr << white.size() << ' ' << black.size() << ' ' << both.size() << '\n';
            vert leaf;

            if (!white.empty() && white.begin()->white == 1) {
                leaf = *white.begin();
                white.erase(white.begin());
            } else {
                if (!black.empty() && black.begin()->black == 1) {
                    leaf = *black.begin();
                    black.erase(black.begin());
                } else {
                    // no leaves :(
                    break;
                }
            }

            if (leaf.white == 1) {
                auto it = white.upper_bound({0, 1, 0});
                if (it == white.end() && !both_white.empty()) {
                    auto u = *both_white.begin();
                    both_white.erase(both_white.begin());
                    both_black.erase(both_black.find(u));
                    
                    u.white--;
                    ans.push_back({leaf.id, u.id, 'W'});
                    if (u.white == 0) {
                        black.insert(u);
                    } else {
                        both_white.insert(u);
                        both_black.insert(u);
                    }
                } else {
                    if (white.empty()) {
                        ok = false;
                        break;
                    }
                    if (it == white.end()) {
                        --it;
                    }
                    auto u = *it;
                    white.erase(it);

                    u.white--;
                    ans.push_back({leaf.id, u.id, 'W'});
                    
                    if (u.white > 0) {
                        white.insert(u);
                    }
                }
            } else {
                auto it = black.upper_bound({0, 0, 1});
                if (it == black.end() && !both_black.empty()) {
                    auto u = *both_black.begin();
                    both_black.erase(both_black.begin());
                    both_white.erase(both_white.find(u));
                    
                    u.black--;
                    ans.push_back({leaf.id, u.id, 'B'});
                    if (u.black == 0) {
                        white.insert(u);
                    } else {
                        both_black.insert(u);
                        both_white.insert(u);
                    }
                } else {
                    if (black.empty()) {
                        ok = false;
                        break;
                    }
                    if (it == black.end()) {
                        --it;
                    }
                    auto u = *it;
                    black.erase(it);

                    u.black--;
                    ans.push_back({leaf.id, u.id, 'B'});
                    
                    if (u.black > 0) {
                        black.insert(u);
                    }
                }
            }
        }

        if (ans.size() == n - 1 && white.empty() && black.empty() && both_black.empty() && both_white.empty() && ok) {
            cout << "Yes\n";
            for (auto it : ans) {
                cout << it.v + 1 << ' ' << it.u + 1 << ' ' << it.color << '\n';
            }
        } else {
            cout << "No\n";
        }
    }
}
