#include <iostream>
#include <vector>
#include <algorithm>
#include <queue>

using namespace std;

using ll = long long;
#define int long long
const int INF = (1e14 + 7);
const int N = 1e6 + 7;

struct node {
    int min_right = INF, min_left = INF;
    int min_left_p = -1, min_right_p = -1;
};

node nds[N];
vector<int> layers[N];
vector<pair<int, int>> g[N];

void solver(int n) {
    int s = 0;
    queue<int> q;
    vector<int> d(n, INF);
    d[s] = 0;
    q.push(s);
    while (!q.empty()) {
        int from = q.front();
        if (from == n - 1) {
            break;
        }
        q.pop();
        for (auto[to, w]: g[from]) {
            if (d[to] > d[from] + 1) {
                d[to] = d[from] + 1;
                q.push(to);
            }
        }
    }

    for (int i = 0; i != n - 1; ++i) {
        if (d[i] == d[n - 1]) {
            d[i] = INF;
        }
    }

    // Fill layers
    for (int i = 0; i < n; i++) {
        if (d[i] != INF) {
            layers[d[i]].push_back(i);
        }
    }

    // Make one-directional and pre-calculate
    {
        for (int i = 1; i <= d[n - 1]; i++) {
            for (int from: layers[i]) {
                for (auto[to, w]: g[from]) {
                    if (d[to] != d[from] - 1) {
                        continue;
                    }

                    if (nds[from].min_left > w) {
                        nds[from].min_left = w;
                        nds[from].min_left_p = to;
                    }

                    if (nds[from].min_left > nds[to].min_left) {
                        nds[from].min_left = nds[to].min_left;
                        nds[from].min_left_p = to;
                    }
                }
            }
        }

        for (int i = d[n - 1] - 1; i >= 0; i--) {
            for (int from: layers[i]) {
                for (auto[to, w]: g[from]) {
                    if (d[to] != d[from] + 1) {
                        continue;
                    }
                    if (nds[from].min_right > w) {
                        nds[from].min_right = w;
                        nds[from].min_right_p = to;
                    }

                    if (nds[from].min_right > nds[to].min_right) {
                        nds[from].min_right = nds[to].min_right;
                        nds[from].min_right_p = to;
                    }
                }
            }
        }
    }

    int good_l = -1, good_r = -1;
    int opt = 0;

    for (int from = 0; from < n; from++) {
        if (d[from] != INF) {
            for (auto[to, w]: g[from]) {
                if (d[from] + 1 != d[to]) {
                    continue;
                }
                if (opt <= w - min(nds[from].min_left, nds[to].min_right)) {
                    opt = w - min(nds[from].min_left, nds[to].min_right);
                    good_l = from;
                    good_r = to;
                }
            }
        }
    }



//  cout << "DEBUG:\n";
//  for (int i = 0; i < n; i++) {
//    cout << "\tID:" << i + 1 << " max:" << nds[i].min_right << " min:" << nds[i].min_left << " opt:"
//         << nds[i].opt << " prev:" << nds[i].opt_prev + 1 << "\n";
//  }

    int cur = good_l;
    vector<int> path_left;
    while (cur != 0 && cur != -1) {
        path_left.push_back(cur);
        cur = nds[cur].min_left_p;
    }
    path_left.push_back(0);
    std::reverse(path_left.begin(), path_left.end());

    cur = good_r;
    vector<int> path_right;
    while (cur != n - 1 && cur != -1) {
        path_left.push_back(cur);
        cur = nds[cur].min_right_p;
    }
    path_left.push_back(n - 1);

    cout << path_right.size() + path_left.size() - 1 << '\n';

    for (auto x: path_left) {
        cout << x + 1 << ' ';
    }
    for (auto x: path_right) {
        cout << x + 1 << ' ';
    }

    cout << "\n";
}


signed main() {
    int n, m;
    cin >> n >> m;
    for (int i = 0; i < m; i++) {
        int a, b, w;
        cin >> a >> b >> w;
        --a, --b;
        g[a].emplace_back(b, w);
        g[b].emplace_back(a, w);
    }
    solver(n);

}
/*
 */
