#include <assert.h>
#include <functional>
#include <iomanip>
#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <cstring>
#include <algorithm>
#include <bitset>
#include <queue>
#include <deque>
#include <stack>
#include <unordered_map>
#include <cmath>

using namespace std;

#define forn(i, n) for (int (i) = 0; (i) < (n); ++(i))
#define all(x) (x).begin(), (x).end()

typedef long long ll;
typedef unsigned int uint;
typedef long double ld;

const int INT_INF= (int)1e9 + 1;
const ll LONG_INF= (ll)1e18 + 1;
const double pi = acos(-1);

const int MAX_N = (int)2e5 + 10;
const int MOD = (int)1e9 + 7;

vector<pair<int, int>> g[MAX_N];
vector<pair<int, int>> sg[MAX_N], rsg[MAX_N];
vector<int> dist;
vector<int> marked;
vector<int> pref_min, pref_max;
vector<int> suf_min, suf_max;
vector<bool> used;
vector<int> pref_min_par, pref_max_par;
vector<int> suf_min_par, suf_max_par;

void bfs(int st) {
    queue<int> q;
    q.push(st);
    dist[st] = 0;
    while (!q.empty()) {
        int v = q.front();
        q.pop();
        for (auto [to, c] : g[v]) {
            if (dist[v] + 1 < dist[to]) {
                dist[to] = dist[v] + 1;
                q.push(to);
            }
            if (dist[v] + 1 == dist[to]) {
                sg[v].push_back({to, c});
                rsg[to].push_back({v, c});
            }
        }
    }
}

void solve() {
    int n, m;
    cin >> n >> m;
    for (int i = 0; i < m; ++i) {
        int u, v, c;
        cin >> u >> v >> c;
        --u, --v;
        g[u].push_back({v, c});
        g[v].push_back({u, c});
    }

    dist.assign(n, INT_INF);
    bfs(0);

    marked.assign(n, 0);
    queue<int> q;

    pref_min.assign(n, INT_INF);
    pref_max.assign(n, -1);
    pref_max_par.assign(n, -1);
    pref_min_par.assign(n, -1);
    q.push(0);
    used.assign(n, false);
    used[0] = true;
    while (!q.empty()) {
        int v = q.front();
        ++marked[v];
        q.pop();
        for (auto [to, c] : sg[v]) {
            if (!used[to])
                q.push(to);
            used[to] = true;
            if (min(pref_min[v], c) < pref_min[to]) {
                pref_min[to] = min(pref_min[v], c);
                pref_min_par[to] = v;
            }

            if (max(pref_max[v], c) > pref_max[to]) {
                pref_max[to] = max(pref_max[v], c);
                pref_max_par[to] = v;
            }

        }
    }

    suf_min.assign(n, INT_INF);
    suf_max.assign(n, -1);
    suf_max_par.assign(n, -1);
    suf_min_par.assign(n, -1);
    q.push(n - 1);
    used.assign(n, false);
    used[n - 1] = true;
    while (!q.empty()) {
        int v = q.front();
        ++marked[v];
        q.pop();
        for (auto [to, c] : rsg[v]) {
            if (!used[to])
                q.push(to);
            used[to] = true;
            if (min(suf_min[v], c) < suf_min[to]) {
                suf_min[to] = min(suf_min[v], c);
                suf_min_par[to] = v;
            }

            if (max(suf_max[v], c) > suf_max[to]) {
                suf_max[to] = max(suf_max[v], c);
                suf_max_par[to] = v;
            }

        }
    }

    int ans_v = -1, mode = -1, ans = 0;
    for (int v = 1; v < n - 1; ++v) {
        if (marked[v] != 2)
            continue;

        //1
        if (abs(pref_min[v] - suf_max[v]) > ans) {
            ans = abs(pref_min[v] - suf_max[v]);
            ans_v = v;
            mode = 1;
        }

        //2
        if (abs(pref_max[v] - suf_min[v]) > ans) {
            ans = abs(pref_max[v] - suf_min[v]);
            ans_v = v;
            mode = 2;
        }
    }

    if (ans_v == -1) {
        cout << 1 << "\n";
        cout << 1 << " " << n;
        return;
    }

    vector<int> p;
    if (mode == 1) {
        int v = ans_v;
        while (v != -1) {
            p.push_back(v);
            v = pref_min_par[v];
        }
        reverse(p.begin(), p.end());
        p.pop_back();
        v = ans_v;
        while (v != -1) {
            p.push_back(v);
            v = suf_max_par[v];
        }
    } else {
        int v = ans_v;
        while (v != -1) {
            p.push_back(v);
            v = pref_max_par[v];
        }
        reverse(p.begin(), p.end());
        p.pop_back();
        v = ans_v;
        while (v != -1) {
            p.push_back(v);
            v = suf_min_par[v];
        }
    }

    cout << (int)p.size() - 1 << "\n";
    for (auto x : p)
        cout << x + 1 << " ";
}

void multitest() {
    int t;
    cin >> t;
    while (t--)
        solve();
}

int main(){
    ios_base::sync_with_stdio(0);
    cin.tie(0), cout.tie(0);
    cout << fixed << setprecision(9);
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    solve();
    //multitest();
#ifdef LOCAL
    cout << "\nTime:\n";
    cout << static_cast<double>(clock()) / CLOCKS_PER_SEC << '\n';
#endif

}