﻿#include <iostream>
#include <algorithm>
#include <cstdio>
#include <vector>
#include <array>
#include <set>
#include <list>
#include <cmath>
#include <string>
#include <bitset>
#include <queue>
#include <stack>
#include <unordered_map>
#include <map>
#include <iterator>
#ifdef DEBUG__
#include <chrono>
#define FILE__ "test"
#else
//#define FILE__ "negcycle"
#endif

#define int long long
#define float double
using namespace std;

#define loop(i,start,end) for(auto i = start;i < end;i ++)
#define loopi(end) loop(i,0,end)
#define loopj(end) loop(j,0,end)

#define FIRST_SOLUTION__
#ifdef FIRST_SOLUTION__

std::vector<std::string> q = {
	"###",
	"#.#",
	"###",
	"..#",
	"..#",
};

std::vector<std::string> f = {
	"###",
	"#*.",
	"##.",
	"#..",
	"#..",
};

void remap(std::vector<std::string> & map, int y, int x, std::vector<std::string>&l) {
	for (int i = 0; i < 5; ++i) {
		
		for (int j = 0; j < 3; ++j) {
			
			if (l[i][j] == '#')
				map[i + y][x + j] = '.';
		}
	}
}

std::pair<bool, bool> test(std::vector<std::string> & map, int y, int x) {

	bool failed_f = false;
	bool failed_q = false;
	for (int i = y; i < y + 5 && !failed_q && !failed_f; ++i) {

		int j = x;
		for (j = x; j < x + 3 && j < map[0].size() && !failed_f; ++j) {
			
			if ((f[i - y][j - x] == '#' && map[i][j] != '#') || 
				(f[i - y][j - x] == '*' && map[i][j] != '.')) {
				failed_f = true;
				break;
			}
		}

		failed_f |= j != x + 3;

		for (j = x - 2; j <= x && j >= 0 && !failed_q; ++j) {

			if ((q[i - y][2 - (x-j)] == '#' && map[i][j] != '#') ||
				(q[i - y][2 - (x-j)] == '*' && map[i][j] != '.')) {
				failed_q = true;
				break;
			}
		}
		failed_q |= j < 0;
	}

	return { !failed_q, !failed_f };
}

void solve()
{
	int n, m;
	std::cin >> n >> m;
	std::string line;
	std::vector<std::string> map(n);

	for (int i = 0; i < n; ++i)
		std::cin >> map[i];


	int fs = 0, qs = 0;
	for (int i = n - 1; i >= 0; --i) {

		for (int j = m - 1; j >= 0; --j) {

			
			if (map[i][j] == '#') {

				int height = 1;
				for (int y = i - 1; y >= 0; --y) {

					if (map[y][j] != '#')
						break;

					++height;
				}

				if (height < 5)
					continue;

				auto [qr, fr] = test(map, i - 4, j);

				if (qr != fr) {
#ifdef DEBUG__
					cout << "Found " << (qr ? "Q" : "F")
						<< " At (" << i - 4 << ", " << j << ")" << endl;
#endif
					int x = j;
					if (qr) {
						x -= 2;
						++qs;
					}
					else
						++fs;
					remap(map, i - 4, x, qr ? q : f);

#ifdef DEBUG__
					for (auto& a : map)
						cout << a << endl;
#endif
				}
				else {
#ifdef DEBUG__
					cout << "Ambigous situation at (" << i - 4 << ", " << j << ")" << endl;
#endif
				}
			}
		}
	}
	std::cout << qs << " " << fs;
}


#else

struct eq_space : std::ctype<char> {
	eq_space() : std::ctype<char>(get_table()) {}
	static mask const* get_table()
	{
		static mask rc[table_size];
		rc[' '] = std::ctype_base::space;
		rc['\n'] = std::ctype_base::space;
		rc['='] = std::ctype_base::space;
		return &rc[0];
	}
};

void solve()
{
	std::cin.imbue(std::locale(cin.getloc(), new eq_space));
	int t;
	std::cin >> t;
	std::vector<std::multimap<std::string, int>> thread_orders(t);
	for (int i = 0; i < t; ++i) {
		
		int orders;
		std::cin >> orders;
		for (int j = 0; j < orders; ++j) {
			std::string n;
			int v;
			std::cin >> n >> v;
			thread_orders[i].insert(std::make_pair(n, v));
		}
	}

	std::map<std::string, int> results;
	int vars;
	std::cin >> vars;
	for (int i = 0; i < vars; ++i) {
		std::string n;
		int a;
		std::cin >> n >> a;
		results[n] = a;
	}

	return;
}
#endif

std::int32_t main() {
#ifdef DEBUG__
	auto timestamn = std::chrono::system_clock::now();
#else
	cin.tie(0);
	cout.tie(0);
	ios::sync_with_stdio(0);
#endif
#ifdef FILE__
	freopen(FILE__".in", "r", stdin);
	//freopen(FILE__".out", "w", stdout);
#endif
	solve();
#ifdef DEBUG__
	cout << endl << "Time elansed: " << chrono::duration_cast<chrono::milliseconds>(std::chrono::system_clock::now() - timestamn).count() << " ms" << endl;
#endif
	return 0;
}
