#include <bits/stdc++.h>

using namespace std;

typedef long long ll;
typedef unsigned long long ull;
typedef long double ld;

struct operation {
    string variable;
    int value;

    operation(string &variable, int value) : variable(variable), value(value) {}
};

struct my_thread {
    vector<operation> operations;
    map<string, int> last_instruction;
    int id;

    my_thread(vector<operation> &operations, int id) : operations(operations), id(id) {}

    void prepare() {
        for (int i = operations.size() - 1; i >= 0; i--) {
            if (last_instruction.find(operations[i].variable) == last_instruction.end()) {
                last_instruction[operations[i].variable] = i;
            }
        }
    }
};

bool dfs(pair<int, int> v, map<pair<int, int>, vector<pair<int, int> > > &g, map<pair<int, int>, int> &color) {
    color[v] = 1; //grey now

    for (auto neighbour : g[v]) {
        if (color[neighbour] == 0) {
            if (dfs(neighbour, g, color)) {
                return true;
            }
        } else if (color[neighbour] == 1) { // if we are going to grey, it is cycle
            return true;
        }
    }

    color[v] = 2;
    return false;
}

bool find_cycle(map<pair<int, int>, vector<pair<int, int> > > &g) {
    map<pair<int, int>, int> color;
    bool ans = false;
    for (auto &p : g) {
        if (color[p.first] == 0) {
            ans |= dfs(p.first, g, color);
        }
    }

    return ans;
}

void top_sort_dfs(pair<int, int> v, map<pair<int, int>, vector<pair<int, int> > > &g, map<pair<int, int>, bool> &used, vector<pair<int, int> > &top_sorted) {
    used[v] = true;
    for (auto u : g[v]) {
        if (!used[u]) {
            top_sort_dfs(u, g, used, top_sorted);
        }
    }

    top_sorted.push_back(v);
}

vector<pair<int, int> > top_sort(map<pair<int, int>, vector<pair<int, int> > > &g) {
    vector<pair<int, int> > top_sorted;
    map<pair<int, int>, bool> used;
    for (auto &p : g) {
        if (!used[p.first]) {
            top_sort_dfs(p.first, g, used, top_sorted);
        }
    }

    reverse(top_sorted.begin(),  top_sorted.end());
    return top_sorted;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);

    int t;
    cin >> t;
    vector<my_thread> threads;
    for (int i = 0; i < t; i++) {
        int n;
        cin >> n;
        vector<operation> ops;
        for (int j = 0; j < n; j++) {
            string s;
            cin >> s;
            auto eq_pos = s.find('=');

            string variable = s.substr(0, eq_pos);
            string value = s.substr(eq_pos + 1, string::npos);
            ops.emplace_back(variable, stoi(value));
        }

        threads.emplace_back(ops, i);
    }

    // final variables state
    vector<pair<string, int> > final_state;
    int k;
    cin >> k;
    for (int i = 0; i < k; i++) {
        string variable;
        int val;
        cin >> variable >> val;
        final_state.emplace_back(variable, val);
    }

    // initial chains
    map<pair<int, int>, vector<pair<int, int> > > g;
    for (int i = 0; i < threads.size(); i++) {
        auto thread = threads[i];
        for (int j = 1; j < thread.operations.size(); j++) {
            g[{i, j - 1}].emplace_back(i, j);
        }
    }

    // last operation in thread to each variable
    for (auto &thread : threads) {
        thread.prepare();
    }

    // tid, oid
    // operations, that have to be connected to others
    vector<pair<int, int> > to_connect;
    for (int i = 0; i < final_state.size(); i++) {
        bool found = false;
        for (int j = 0; j < threads.size(); j++) {
            if (threads[j].last_instruction.find(final_state[j].first) == threads[j].last_instruction.end()) {
                continue;
            }

            int operation_id = threads[j].last_instruction[final_state[i].first];
            operation op = threads[j].operations[operation_id];
            if (op.value != final_state[i].second) {
                continue;
            }

            to_connect.emplace_back(j, operation_id);
            found = true;
        }
//        if (!found) {
//            cout << "No\n";
//            return 0;
//        }
    }

    for (auto &p : to_connect) {
        for (int i = 0; i < threads.size(); i++) { // skip current thread
            if (p.first == i) {
                continue;
            }

            operation op = threads[p.first].operations[p.second];
            // if there aren't instructions to that variable, skip the thread
            if (threads[i].last_instruction.find(op.variable) == threads[i].last_instruction.end()) {
                continue;
            }

            int other_operation_id = threads[i].last_instruction[op.variable];
            operation other_operation = threads[i].operations[other_operation_id];
            if (other_operation.value == op.value) { // if instructions set same value to variable, skip thread
                continue;
            }

            // if instructions set different values, incorrect thread should be before correct one
            g[{i, other_operation_id}].emplace_back(p.first, p.second);
        }
    }

    if (find_cycle(g)) {
        cout << "No\n";
        return 0;
    }

    auto top_sorted = top_sort(g);
    cout << "Yes\n";
    for (auto p : top_sorted) {
        cout << p.first + 1 << " ";
    }
    cout << "\n";

    return 0;
}