"""
usefull snippets:
    - map(int, input().split())
    - map(int, sys.stdin.readline().split()))
    - int(input())
    - int(sys.stdin.readline().strip())

    - sys.stdout.write()
    - sys.stdout.write(" ".join(map(str, c) # writes c - collection of ints
"""
# import collections
import sys
from bisect import bisect_left

# recursion increase
# sys.setrecursionlimit(10000)

# number with big precision
# from decimal
# getcontext().prec = 10_000


# input parser
# n, d, li, ld, ls, s - int, float, list of ints, list of floats, list of string, string
# lists are lines with ' '(space) delimiters
from collections import defaultdict


def get(format: str, wrap_lists=True):
    result = []
    selected_types = format.split()
    for type in selected_types:
        inputStr = sys.stdin.readline().strip()
        if type == 'n':
            result.append(int(inputStr))
        elif type == 'd':
            result.append(float(inputStr))
        elif type == 's':
            result.append(inputStr)
        elif type == 'li':
            mapped = map(int, inputStr.split())
            result.append(list(mapped) if wrap_lists else mapped)
        elif type == 'ld':
            mapped = map(float, inputStr.split())
            result.append(list(mapped) if wrap_lists else mapped)
        elif type == 'ls':
            result.append(list(inputStr.split()))
        elif type == 'nls':
            n = int(inputStr)
            A = get(" ".join(["li"] * n))

            result.append(n)
            result.append(A)

    if len(result) == 1:
        return result[0]
    return result


# splits aaasfffsga into (aaa, s, fff, s, g, a) blocks with signature (startPos, length, type)
def split_into_blocks(s):
    blocks = []

    i = 0
    curr_type = s[0]
    curr_len = 0
    while i < len(s):
        if s[i] == curr_type:
            curr_len += 1
            i += 1
        else:
            blocks.append((i - curr_len, curr_len, curr_type))
            curr_type = s[i]
            curr_len = 0

    blocks.append((i - curr_len, curr_len, curr_type))

    return blocks


# longest common prefix
def get_lcp(s, suffix_array):
    s = s + "$"
    n = len(s)
    lcp = [0] * (n)
    pos = [0] * (n)
    for i in range(n - 1):
        pos[suffix_array[i]] = i
    k = 0
    for i in range(n - 1):
        if k > 0:
            k -= 1
        if pos[i] == n - 1:
            lcp[n - 1] = -1
            k = 0
            continue
        else:
            j = suffix_array[pos[i] + 1]
            while max([i + k, j + k]) < n and s[i + k] == s[j + k]:
                k += 1
            lcp[pos[i]] = k

    return lcp


def get_suffix_array(word):
    suffix_array = [("", len(word))]

    for position in range(len(word)):
        sliced = word[len(word) - position - 1:]
        suffix_array.append((sliced, len(word) - position - 1))

    suffix_array.sort(key=lambda x: x[0])
    return [item[1] for item in suffix_array]


def get_ints():
    return map(int, sys.stdin.readline().strip().split())


def bin_search(collection, element):
    i = bisect_left(collection, element)
    if i != len(collection) and collection[i] == element:
        return i
    else:
        return -1


def main():
    t = get('n')
    programs = []

    comms = set()

    for _ in range(t):
        program = []
        ti = get('n')
        for i in range(ti):
            var, val = get('s').split('=')
            program.append((var, int(val)))
            comms.add(_ * 100 + i)
        programs.append(program)
    result = {}
    n = get('n')
    for i in range(n):
        var, val = get('s').split(' ')
        result[var] = int(val)

    correctAssigns = defaultdict(set)
    assigns = defaultdict(set)
    graph = defaultdict(set)
    for i in range(len(programs)):
        program = programs[i]
        for j in range(0, len(program)):
            command = program[j]
            if j > 0:
                graph[i * 100 + j].add(i * 100 + j - 1)
            if result[command[0]] == command[1]:
                correctAssigns[command[0]].add(i * 100 + j)
            else:
                assigns[command[0]].add(i * 100 + j)
    if len(correctAssigns) != len(result):
        print("No")
        return

    for k in correctAssigns:
        for c in correctAssigns[k]:
            graph[c].update(assigns[k])

    roots = set()
    for i in range(len(programs)):
        program = programs[i]
        last = program[-1]
        key = i * 100 + len(program) - 1
        if key in correctAssigns[last[0]]:
            roots.add(key)

    finishedVars = set()
    for r in roots:
        prog = r // 100
        comm = r % 100
        finishedVars.add(programs[prog][comm][0])

    commands = list(roots)
    visited = set()
    queue = []
    for v in roots:
        visited.add(v)
        queue.extend(graph[v].difference(visited))
        visited.update(graph[v])

    while len(queue) > 0:
        e = queue.pop(len(queue) - 1)
        prog = e // 100
        comm = e % 100
        var = programs[prog][comm]
        if var[0] in finishedVars:
            commands.append(e)
            queue.extend(graph[e].difference(visited))
            visited.update(graph[e])
        elif result[var[0]] == var[1]:
            commands.append(e)
            finishedVars.add(var[0])
            queue.extend(graph[e].difference(visited))
            visited.update(graph[e])
        else:
            queue.insert(0, e)

    for c in comms.difference(visited):
        commands.append(c)

    print(' '.join(map(lambda v: str(v // 100 + 1), reversed(commands))))


if __name__ == "__main__":
    main()

# 3
# 2
# a=2
# b=1
# 2
# a=1
# c=2
# 2
# b=2
# c=1
# 3
# a 1
# b 1
# c 1
