#include <iostream>
#include <algorithm>
#include <string>

using namespace std;

const int MAXLEN = 100100;
const int ALPHABET = 26;

struct Node {
	int go[ALPHABET] = { 0 };
	bool isEnd = false;
	int count = 0;
};

Node trie[MAXLEN];
int trieSize = 1;

bool canGo(int v, char ch) {
	return trie[v].go[ch - 'a'] != 0;
}

int go(int v, char ch) {
	return trie[v].go[ch - 'a'];
}

bool isEnd(int v) {
	return trie[v].isEnd;
}

bool search(const string& s) {
	int v = 0;
	for (char c : s) {
		if (!canGo(v, c))
			return false;
		v = go(v, c);
	}

	return isEnd(v);
}

void createNewTransition(int v, char c) {
	trie[v].go[c - 'a'] = trieSize++;
}

void insert(const string& s) {
	int v = 0;
	for (char c : s) {
		trie[v].count++;
		if (!canGo(v, c))
			createNewTransition(v, c);
		v = go(v, c);
	}
	trie[v].count++;
	trie[v].isEnd = true;
}

int erase(int v, int d)
{
	for (int i = 0; i < 26; i++) {
		if (trie[v].go[i] == d) {

			trie[v].count -= trie[d].count;
			trie[v].go[i] = 0;
			return trie[d].count;
		}
	}

	for (int i = 0; i < 26; i++) {
		if (trie[v].go[i] != 0) {
			int cnt = erase(trie[v].go[i], d);
			if (cnt > 0) {
				trie[v].count -= cnt;
				if (trie[trie[v].go[i]].count == 0)
					trie[v].go[i] = 0;
				return cnt;
			}
		}
	}

	return false;
}

int findMax(int v, int k) {
	if (trie[v].count <= k)
		return v;
	int max = 0, vmax = -1;
	for (int i = 0; i < 26; i++) {
		if (trie[v].go[i] != 0) {
			if (trie[trie[v].go[i]].count <= k) {
				if (trie[trie[v].go[i]].count > max) {
					max = trie[trie[v].go[i]].count, vmax = trie[v].go[i];
				}
			}
			else if (trie[v].go[i] != v) {
				int mv = findMax(trie[v].go[i], k);
				if (mv > 0 && trie[mv].count > max)
					max = trie[mv].count, vmax = mv;
			}				
		}
	}

	return vmax;
}

int main() {
	int N, K;
	cin >> N >> K;
	string s;
	for (int i = 0; i < N; i++) {
		cin >> s;
		insert(s);
	}

	int num = 0, m = 1;
	while (trie[0].count > 0)
	{
		m = findMax(0, K);
		if (m >= 0) erase(0, m);
		//cout << m << ' ' << trie[0].count << endl;
		num++;
	}
	cout << num << endl;

	return 0;
}