#define _USE_MATH_DEFINES
#define _CRT_SECURE_NO_WARNINGS

#include <algorithm>
#include <cmath>
#include <iomanip>
#include <iostream>
#include <map>
#include <numeric>
#include <string>
#include <vector>
#include <queue>

using namespace std;

vector<vector<int>> g_adj;

vector<map<int, int>> g_cs;

// Function to form edge between
// two vertices src and dest
void add_edge(vector<vector<int>> &adj,
	int src, int dest)
{
	adj[src].push_back(dest);
	adj[dest].push_back(src);
}

// Function which finds all the paths
// and stores it in paths array
void find_paths(vector<vector<int> >& paths,
	vector<int>& path,
	vector<vector<int>> &parent,
	int n, int u)
{
	// Base Case
	if (u == -1) {
		paths.push_back(path);
		return;
	}

	// Loop for all the parents
	// of the given vertex
	for (int par : parent[u]) {

		// Insert the current
		// vertex in path
		path.push_back(u);

		// Recursive call for its parent
		find_paths(paths, path, parent,
			n, par);

		// Remove the current vertex
		path.pop_back();
	}
}

// Function which performs bfs
// from the given source vertex
void bfs(vector<vector<int>> &adj,
	vector<vector<int>> &parent,
	int n, int start)
{
	// dist will contain shortest distance
	// from start to every other vertex
	vector<int> dist(n, INT_MAX);

	queue<int> q;

	// Insert source vertex in queue and make
	// its parent -1 and distance 0
	q.push(start);
	parent[start] = { -1 };
	dist[start] = 0;

	// Until Queue is empty
	while (!q.empty()) {
		int u = q.front();
		q.pop();
		for (int v : adj[u]) {
			if (dist[v] > dist[u] + 1) {

				// A shorter distance is found
				// So erase all the previous parents
				// and insert new parent u in parent[v]
				dist[v] = dist[u] + 1;
				q.push(v);
				parent[v].clear();
				parent[v].push_back(u);
			}
			else if (dist[v] == dist[u] + 1) {

				// Another candidate parent for
				// shortes path found
				parent[v].push_back(u);
			}
		}
	}
}

// Function which prints all the paths
// from start to end
void print_paths(vector<vector<int>> &adj,
	int n, int start, int end, vector<map<int, int>> &cs)
{
	vector<vector<int> > paths;
	vector<int> path;
	vector<vector<int>> parent(n);

	// Function call to bfs
	bfs(adj, parent, n, start);

	// Function call to find_paths
	find_paths(paths, path, parent, n, end);

	int a = INT_MIN;
	size_t i_a;
	for (size_t j = 0; j < paths.size(); j++) {
		auto& v = paths[j];

		// Since paths contain each
		// path in reverse order,
		// so reverse it
		reverse(v.begin(), v.end());

		int ma = INT_MIN, mi = INT_MAX;
		// Print node for the current path
		for (size_t ve = 0; ve + 1 < v.size(); ve++) {
			ma = max(ma, cs[v[ve]][v[ve + 1]]);
			mi = min(mi, cs[v[ve]][v[ve + 1]]);
		}

		if (ma - mi > a) {
			a = ma - mi;
			i_a = j;
		}
	}

	std::cout << paths[i_a].size() - 1 << std::endl;
	for (auto ve : paths[i_a]) {
		std::cout << ve + 1 << " ";
	}
	std::cout << std::endl;
}

// Driver Code
int main()
{
	// Number of vertices
	int n, m;
	scanf("%d%d", &n, &m);

	g_adj.resize(n);
	g_cs.resize(n);

	// array of vectors is used
	// to store the graph
	// in the form of an adjacency list

	for (int i = 0; i < m; i++) {
		int v, u, c;
		scanf("%d%d%d", &v, &u, &c);
		
		v--;
		u--;

		add_edge(g_adj, v, u);
		g_cs[v][u] = c;
		g_cs[u][v] = c;
	}

	// Given source and destination
	int src = 0;
	int dest = n - 1;

	// Function Call
	print_paths(g_adj, n, src, dest, g_cs);

	return 0;
}
