﻿#include <iostream>
#include <string>
#include <map>
#include <unordered_map>
#include <vector>
#include <unordered_set>
#include <algorithm>
#include <queue>

using namespace std;

struct hash_pair {
	template <class T1, class T2>
	size_t operator()(const pair<T1, T2>& p) const
	{
		auto hash1 = hash<T1>{}(p.first);
		auto hash2 = hash<T2>{}(p.second);
		return hash1 ^ hash2;
	}
};

int n;
unordered_map<pair<int, int>, long long, hash_pair> colors;
unordered_map<int, vector<int>> graph;
long long mx_diff = -1;
vector<int> best_path;


struct Step {
	int cur, len;
};

void dfs(vector<int>& dist, vector<int>& path, Step step, int t) {
	if (step.len == 0) {
		long long mn = 1e18, mx = -1;
		for (int j = 0; j < path.size() - 1; j++)
		{
			int v1 = path[j];
			int v2 = path[j + 1];
			auto c = colors[make_pair(min(v1, v2), max(v1, v2))];
			if (c > mx)
				mx = c;
			if (c < mn)
				mn = c;
		}
		if ((mx - mn) > mx_diff) {
			mx_diff = mx - mn;
			best_path = path;
		}
		return;
	}

	for (int next : graph[step.cur]) {
		if (dist[next] == step.len - 1) {
			path[step.len - 1] = next;
			dfs(dist, path, { next, step.len - 1 }, n - 1);
		}
	}
}

void bfs(int s, int t) {
	vector<int> dist(n, n);
	dist[s] = 0;
	queue<int> q;
	q.push(s);

	while (!q.empty()) {
		int v = q.front();
		q.pop();
		for (int u : graph[v]) {
			if (dist[u] > dist[v] + 1) {
				dist[u] = dist[v] + 1;
				q.push(u);
			}
		}
	}

	vector<int> path(dist[t] + 1);
	path[dist[t]] = n - 1;
	dfs(dist, path, { n - 1, dist[t] }, n - 1);
}

int main()
{
	ios::sync_with_stdio(false);
	cin.tie(0);

    int m;
    cin >> n >> m;
	for (size_t i = 0; i < m; i++)
	{
		int v, u;
		long long c;
		cin >> v >> u >> c;
		v -= 1;
		u -= 1;
		colors.insert(make_pair(make_pair(min(u, v), max(u, v)), c));

		if (graph.find(u) == graph.end())
			graph[u] = vector<int>();
		graph[u].push_back(v);
		if (graph.find(v) == graph.end())
			graph[v] = vector<int>();
		graph[v].push_back(u);
	}

	bfs(0, n - 1);

	cout << best_path.size() - 1 << endl;
	for (int i = 0; i < best_path.size(); i++)
	{
		cout << best_path[i] + 1 << ' ';
	}
	cout << endl;
}